@@ -1,4 +1,4 @@
-__version__ = '0.1.3'
+__version__ = '0.2.0'
 
 import sys, os
 from time import sleep
@@ -7,7 +7,7 @@ def delete_line(num):
 	CURSOR_UP_ONE = '\x1b[1A' 
 	ERASE_LINE = '\x1b[2K' 
 	for i in range(num):
-    sys.stdout.write(CURSOR_UP_ONE) 
+		sys.stdout.write(CURSOR_UP_ONE) 
 		sys.stdout.write(ERASE_LINE)
 def clear():
 	os.system('clear')
@@ -28,4 +28,8 @@ def slow_print(*strings, time = 0.045, sep = ' ', end = '\n', file = sys.stdout)
 	file.write(end)
 	file.flush()
 def wait(time = 1):
-  sleep(time)
\ No newline at end of file
+	sleep(time)
+def rgb(r, g, b):
+		return "\033[38;2;{};{};{}m".format(r, g, b)
+def rgb_reset():
+	return "\033[38;2;255;255;255m"
\ No newline at end of file
